﻿# -*- coding: utf-8 -*-
##****************************************************************************         
#     AI model for wine classification with Keras+tf  ver.1                  *
# from https://qiita.com/tanakadaichi_1989/items/c655d93a1fae56f2be07        *
# input data from  http://archive.ics.uci.edu/ml/machine-learning-databases  *
#             /wine-quality/winequality-red.csv                              *
# modified by M. Kogoshi & S. Kogoshi                                        * 
##****************************************************************************

import keras
from keras.models import Sequential
from keras.layers import Dense, Activation, Dropout
import numpy as np
import matplotlib.pyplot as plt
import sys
import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.preprocessing import StandardScaler
from sklearn import svm
from sklearn.metrics import accuracy_score
from keras.datasets import fashion_mnist
from keras.optimizers import RMSprop
from keras.optimizers import Adam


savefile = "test1202.h5"#sys.argv[1]

# load of train_data

data_set = pd.read_csv("winequality_train.csv",sep=",",header=0)

#separation of input(x) and target(y)

x = pd.DataFrame(data_set.drop("quality",axis=1))
y = pd.DataFrame(data_set["quality"])

# standardization of x
scaler = StandardScaler()
scaler.fit(x)
x = scaler.transform(x)

# input and output for keras
x = x.astype(np.float)


# to keras format
y = keras.utils.to_categorical(y, 10)

# 4 (or 5) layers
model = Sequential()
# input layer(input_shapeは特徴量数を入れる）
model.add(Dense(units=50, activation='relu', input_shape=(11,)))
# Dropout
model.add(Dropout(0.2))
# second layer
model.add(Dense(units=50, activation='relu', input_shape=(11,)))
# Dropout
model.add(Dropout(0.2))
# third layer
model.add(Dense(units=50, activation='relu', input_shape=(11,)))
# Dropout
model.add(Dropout(0.2))
# 4th layer
#model.add(Dense(units=50, activation='relu', input_shape=(11,)))
# Dropout
#model.add(Dropout(0.2))
# output layer
model.add(Dense(units=10, activation='softmax'))

# compile
model.compile(loss='mean_squared_error', optimizer=RMSprop(), metrics=['accuracy'])

# learning

history = model.fit(x,y, batch_size=200, epochs=200, verbose=1, validation_split=0.05)

# save model
#model.save_weights(savefile)

# load of test_data

data_set2 = pd.read_csv("winequality_test.csv",sep=",",header=0)

#separation of input(x) and target(y)

x2 = pd.DataFrame(data_set2.drop("quality",axis=1))
y2 = pd.DataFrame(data_set2["quality"])

# standardization of x2

x2 = scaler.transform(x2)

# input and output for keras
x_test = x2.astype(np.float)


# to keras format
y_test = keras.utils.to_categorical(y2, 10)

# result
score = model.evaluate(x_test,y_test, verbose=1)

print("test loss:",score[0])

print("Test accuracy:",score[1])

plt.plot(history.history['acc'])
plt.plot(history.history['val_acc'])
plt.title('model accracy')
plt.xlabel('epoch')
plt.ylabel('accuracy')
plt.legend(['acc','val_acc'],loc='lower right')
plt.show()

plt.plot(history.history['loss'])
plt.plot(history.history['val_loss'])
plt.title('model loss')
plt.xlabel('epoch')
plt.ylabel('loss')
plt.legend(['loss','val_loss'],loc='lower right')
plt.show()

# prediction from here

sample = [7.9,0.35,0.46,5,0.078,15,37,0.9973,3.35,0.86,12.8]
print(sample)
sample = np.array(sample)
pridict = model.predict_classes(sample.reshape(1,-1),batch_size=1,verbose=0)
print("-- prediction --")
print(pridict)
